@@ -1,8 +1,12 @@
 """Test utilities"""
 
+import sys
 import six
 import enum
-import collections
+try:
+    import collections.abc as collections_abc  # python 3.3+
+except ImportError:
+    import collections as collections_abc
 
 # Local imports
 from . import DevState, GreenMode
@@ -22,6 +26,12 @@ except ImportError:
 
 __all__ = ('DeviceTestContext', 'SimpleDevice')
 
+PY3 = sys.version_info >= (3,)
+
+# char \x00 cannot be sent in a DevString. All other 1-255 chars can
+ints = tuple(range(1, 256))
+bytes_devstring = bytes(ints) if PY3 else ''.join(map(chr, ints))
+str_devstring = bytes_devstring.decode('latin-1')
 
 # Test devices
 
@@ -58,15 +68,21 @@ class BadEnumDuplicates(enum.IntEnum):
 
 # Helpers
 
+# Note on Tango properties using the Tango File database:
+# Tango file database cannot handle properties with '\n'. It doesn't
+# handle '\' neither. And it cuts ASCII extended characters. That is
+# why you will find that all property related tests are truncated to
+# the first two values of the arrays below
+
 TYPED_VALUES = {
-    int: (1, 2),
-    float: (2.71, 3.14),
-    str: ('hey hey', 'my my'),
-    bool: (False, True),
-    (int,): ([1, 2, 3], [9, 8, 7]),
-    (float,): ([0.1, 0.2, 0.3], [0.9, 0.8, 0.7]),
-    (str,): (['ab', 'cd', 'ef'], ['gh', 'ij', 'kl']),
-    (bool,): ([False, False, True], [True, False, False])}
+    int: (1, 2, -65535, 23),
+    float: (2.71, 3.14, -34.678e-10, 12.678e+15),
+    str: ('hey hey', 'my my', bytes_devstring, str_devstring),
+    bool: (False, True, True, False),
+    (int,): ([1, 2, 3], [9, 8, 7], [-65535, 2224], [0, 0]),
+    (float,): ([0.1, 0.2, 0.3], [0.9, 0.8, 0.7], [-6.3232e-3], [0.0, 12.56e+12]),
+    (str,): (['ab', 'cd', 'ef'], ['gh', 'ij', 'kl'], 10*[bytes_devstring], 10*[str_devstring]),
+    (bool,): ([False, False, True], [True, False, False], [False], [True])}
 
 
 def repr_type(x):
@@ -83,7 +99,7 @@ if numpy and pytest:
         if isinstance(a, six.string_types):
             assert a == b
             return
-        if isinstance(a, collections.Sequence) and len(a) and isinstance(a[0], six.string_types):
+        if isinstance(a, collections_abc.Sequence) and len(a) and isinstance(a[0], six.string_types):
             assert list(a) == list(b)
             return
         try:
@@ -95,6 +111,18 @@ if numpy and pytest:
 
 if pytest:
 
+    def create_result(dtype, value):
+        if dtype == str:
+            if PY3:
+                if isinstance(value, six.binary_type):
+                    return value.decode('latin-1')
+            else:
+                if isinstance(value, six.text_type):
+                    return value.encode('latin-1')
+        elif dtype == (str,):
+            return [create_result(str, v) for v in value]
+        return value
+
     @pytest.fixture(params=DevState.values.values())
     def state(request):
         return request.param
@@ -103,7 +131,9 @@ if pytest:
         params=list(TYPED_VALUES.items()),
         ids=lambda x: repr_type(x[0]))
     def typed_values(request):
-        return request.param
+        dtype, values = request.param
+        expected = lambda v: create_result(dtype, v)
+        return dtype, values, expected
 
     @pytest.fixture(params=GreenMode.values.values())
     def green_mode(request):
